==> zio-aws-ec2_2.13-5.17.104.13-sources.jar: zio/aws/ec2/model/PeeringConnectionOptionsRequest.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class PeeringConnectionOptionsRequest(
    allowDnsResolutionFromRemoteVpc: Option[Boolean] = None,
    allowEgressFromLocalClassicLinkToRemoteVpc: Option[Boolean] = None,
    allowEgressFromLocalVpcToRemoteClassicLink: Option[Boolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.PeeringConnectionOptionsRequest = {
    import PeeringConnectionOptionsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.PeeringConnectionOptionsRequest
      .builder()
      .optionallyWith(
        allowDnsResolutionFromRemoteVpc.map(value => value: java.lang.Boolean)
      )(_.allowDnsResolutionFromRemoteVpc)
      .optionallyWith(
        allowEgressFromLocalClassicLinkToRemoteVpc.map(value =>
          value: java.lang.Boolean
        )
      )(_.allowEgressFromLocalClassicLinkToRemoteVpc)
      .optionallyWith(
        allowEgressFromLocalVpcToRemoteClassicLink.map(value =>
          value: java.lang.Boolean
        )
      )(_.allowEgressFromLocalVpcToRemoteClassicLink)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.PeeringConnectionOptionsRequest.ReadOnly =
    zio.aws.ec2.model.PeeringConnectionOptionsRequest.wrap(buildAwsValue())
}
object PeeringConnectionOptionsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.PeeringConnectionOptionsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.PeeringConnectionOptionsRequest =
      zio.aws.ec2.model.PeeringConnectionOptionsRequest(
        allowDnsResolutionFromRemoteVpc.map(value => value),
        allowEgressFromLocalClassicLinkToRemoteVpc.map(value => value),
        allowEgressFromLocalVpcToRemoteClassicLink.map(value => value)
      )
    def allowDnsResolutionFromRemoteVpc: Option[Boolean]
    def allowEgressFromLocalClassicLinkToRemoteVpc: Option[Boolean]
    def allowEgressFromLocalVpcToRemoteClassicLink: Option[Boolean]
    def getAllowDnsResolutionFromRemoteVpc: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField(
        "allowDnsResolutionFromRemoteVpc",
        allowDnsResolutionFromRemoteVpc
      )
    def getAllowEgressFromLocalClassicLinkToRemoteVpc
        : ZIO[Any, AwsError, Boolean] = AwsError.unwrapOptionField(
      "allowEgressFromLocalClassicLinkToRemoteVpc",
      allowEgressFromLocalClassicLinkToRemoteVpc
    )
    def getAllowEgressFromLocalVpcToRemoteClassicLink
        : ZIO[Any, AwsError, Boolean] = AwsError.unwrapOptionField(
      "allowEgressFromLocalVpcToRemoteClassicLink",
      allowEgressFromLocalVpcToRemoteClassicLink
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.PeeringConnectionOptionsRequest
  ) extends zio.aws.ec2.model.PeeringConnectionOptionsRequest.ReadOnly {
    override val allowDnsResolutionFromRemoteVpc: Option[Boolean] = scala
      .Option(impl.allowDnsResolutionFromRemoteVpc())
      .map(value => value: Boolean)
    override val allowEgressFromLocalClassicLinkToRemoteVpc: Option[Boolean] =
      scala
        .Option(impl.allowEgressFromLocalClassicLinkToRemoteVpc())
        .map(value => value: Boolean)
    override val allowEgressFromLocalVpcToRemoteClassicLink: Option[Boolean] =
      scala
        .Option(impl.allowEgressFromLocalVpcToRemoteClassicLink())
        .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.PeeringConnectionOptionsRequest
  ): zio.aws.ec2.model.PeeringConnectionOptionsRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ec2_2.13-5.19.8.1-sources.jar: zio/aws/ec2/model/PeeringConnectionOptionsRequest.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class PeeringConnectionOptionsRequest(
    allowDnsResolutionFromRemoteVpc: Optional[Boolean] = Optional.Absent,
    allowEgressFromLocalClassicLinkToRemoteVpc: Optional[Boolean] =
      Optional.Absent,
    allowEgressFromLocalVpcToRemoteClassicLink: Optional[Boolean] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.PeeringConnectionOptionsRequest = {
    import PeeringConnectionOptionsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.PeeringConnectionOptionsRequest
      .builder()
      .optionallyWith(
        allowDnsResolutionFromRemoteVpc.map(value => value: java.lang.Boolean)
      )(_.allowDnsResolutionFromRemoteVpc)
      .optionallyWith(
        allowEgressFromLocalClassicLinkToRemoteVpc.map(value =>
          value: java.lang.Boolean
        )
      )(_.allowEgressFromLocalClassicLinkToRemoteVpc)
      .optionallyWith(
        allowEgressFromLocalVpcToRemoteClassicLink.map(value =>
          value: java.lang.Boolean
        )
      )(_.allowEgressFromLocalVpcToRemoteClassicLink)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.PeeringConnectionOptionsRequest.ReadOnly =
    zio.aws.ec2.model.PeeringConnectionOptionsRequest.wrap(buildAwsValue())
}
object PeeringConnectionOptionsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.PeeringConnectionOptionsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.PeeringConnectionOptionsRequest =
      zio.aws.ec2.model.PeeringConnectionOptionsRequest(
        allowDnsResolutionFromRemoteVpc.map(value => value),
        allowEgressFromLocalClassicLinkToRemoteVpc.map(value => value),
        allowEgressFromLocalVpcToRemoteClassicLink.map(value => value)
      )
    def allowDnsResolutionFromRemoteVpc: Optional[Boolean]
    def allowEgressFromLocalClassicLinkToRemoteVpc: Optional[Boolean]
    def allowEgressFromLocalVpcToRemoteClassicLink: Optional[Boolean]
    def getAllowDnsResolutionFromRemoteVpc: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField(
        "allowDnsResolutionFromRemoteVpc",
        allowDnsResolutionFromRemoteVpc
      )
    def getAllowEgressFromLocalClassicLinkToRemoteVpc
        : ZIO[Any, AwsError, Boolean] = AwsError.unwrapOptionField(
      "allowEgressFromLocalClassicLinkToRemoteVpc",
      allowEgressFromLocalClassicLinkToRemoteVpc
    )
    def getAllowEgressFromLocalVpcToRemoteClassicLink
        : ZIO[Any, AwsError, Boolean] = AwsError.unwrapOptionField(
      "allowEgressFromLocalVpcToRemoteClassicLink",
      allowEgressFromLocalVpcToRemoteClassicLink
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.PeeringConnectionOptionsRequest
  ) extends zio.aws.ec2.model.PeeringConnectionOptionsRequest.ReadOnly {
    override val allowDnsResolutionFromRemoteVpc: Optional[Boolean] =
      zio.aws.core.internal
        .optionalFromNullable(impl.allowDnsResolutionFromRemoteVpc())
        .map(value => value: Boolean)
    override val allowEgressFromLocalClassicLinkToRemoteVpc: Optional[Boolean] =
      zio.aws.core.internal
        .optionalFromNullable(impl.allowEgressFromLocalClassicLinkToRemoteVpc())
        .map(value => value: Boolean)
    override val allowEgressFromLocalVpcToRemoteClassicLink: Optional[Boolean] =
      zio.aws.core.internal
        .optionalFromNullable(impl.allowEgressFromLocalVpcToRemoteClassicLink())
        .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.PeeringConnectionOptionsRequest
  ): zio.aws.ec2.model.PeeringConnectionOptionsRequest.ReadOnly = new Wrapper(
    impl
  )
}
